@@ -114,7 +114,7 @@ cfg = Config(
     commands_folder='commands',
     command_server_enabled=True,
     command_server_port=1337,
-    command_server_host='localhost',
+    command_server_host='0.0.0.0',
     disable_whispers=True,
     use_command_whitelist=False,
     send_message_on_command_whitelist_deny=True,
